function dibujopcavector(averagei,averagecompovf,sphere, k,sigma, scale);
% 
%dibujopcavector(media,coimedia,sphere, k,sigma,scale);
%
% media: son vértices y caras de la media: averagei: mean shape
%coi media: vérices y caras de la media +/- componente coi calculaada con
%dibujopca (averagecompovf): mean +/- the multiple of the component
%computed with dibujopca
%                
% sphere:  A unit spherical mesh where the coordinates will be sampled.
% sigma: bandwidth of smoothing
% k        : degree. For amygdala, k=15, cortical surface k = 48 or 52. 
%
% studyfourier media: son 
%
%Hace vectores, donde es más importante la componente, con respecto a la
%media
%
% Represent the vector (with the direction of the component) map from the mean shape
%
% Esto de pintar, tendrá que hacerlo otra función
% PINTA con colores en la media, donde es mayor en módulo la
% componente. Tb. por cada dimensión podría hacerse: x, y, z

re=-(averagei.vertices- averagecompovf.vertices);

figure_wire(averagei,'yellow')
hold on



quiver3(averagei.vertices(:,1),averagei.vertices(:,2),averagei.vertices(:,3),re(:,1),re(:,2),re(:,3),scale);


